#!/usr/bin/python -tt
#
# Van Assche Alphonse <alcapcom@gmail.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import os
import sys
import signal
import getopt
from xselector import XselectorError
from xselector import Xselector
from rhpl.translate import _, N_,textdomain

##
## I18N
## 
import gettext
gettext.bindtextdomain ("XORG_CONF_FILE", "/usr/share/locale")
gettext.textdomain ("system-config-xselector")
_=gettext.gettext

# Global vars
verboseOutput = False
ui= True
xOption = ""

def usage():
    print \
_("""Usage: system-config-xselector [OPTIONS]
Options:
  -h, --help        display this help and exit
  -v, --verbose     display what the program is doing more verbosely
      --set-<key>   change the value of a specific configuration key.

        currently supported keys are:

        aiglx       enable aiglx support
        xgl         enable xgl support
        noglx       disable aiglx and xgl support
                    
""")

if __name__ == '__main__':
    signal.signal(signal.SIGINT, signal.SIG_DFL)

try:
    (opts, rest_args) = getopt.getopt(sys.argv[1:],"vo:h",
                               ["help", "verbose",
                                "set-aiglx", "set-xgl", "set-noglx"])
except (getopt.GetoptError), e:
    print e
    print
    usage()
    sys.exit(1)

for (opt, value) in opts:
    if opt == "-v" or opt == "--verbose":
        verboseOutput = True
        xSelector = Xselector(verboseOutput)
    if opt == "-h" or opt == "--help":
        usage()
        sys.exit(1)
    if opt[:6] == "--set-":
        ui = False
        xOption = opt[6:]
        xSelector = Xselector(verboseOutput)
        
if ui and os.environ.has_key("DISPLAY"):
    import gtk
    from xselectorDialog import XselectorDialog
    try: 
        XselectorDialog(verboseOutput)
        gtk.main()
    except XselectorError, (errMsg):
        errorDialog = gtk.MessageDialog(parent = None,
             type = gtk.MESSAGE_ERROR, 
             buttons = gtk.BUTTONS_CLOSE,
             message_format = str(errMsg) + "\n\n" + _(
                  "That problem must fixed, to be able to use this GUI!"))
        errorDialog.set_icon_from_file(Xselector().icon)
        errorDialog.set_title (_("Error"))
        errorDialog.run()
        errorDialog.destroy()
        sys.exit(1)
else:
    try:
        if xOption == "aiglx":
            xSelector.enableAiglx()
            print _("Aiglx is Enabled")
        elif xOption == "xgl":
            xSelector.enableXgl()
            print _("Xgl is Enabled")
        elif xOption == "noglx":
            xSelector.disableAllGlxStuff()
            print _("Aiglx and Xgl are disabled")
        else:
            usage()
    except XselectorError, (errMsg):
        print errMsg
 
