#!/usr/bin/python -tt
#
# Van Assche Alphonse <alcapcom@gmail.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from xselector import XselectorError
from xselector import Xselector
import sys

import os
import pygtk
pygtk.require("2.0")
import gtk
import gtk.glade
from rhpl.translate import _, N_

# the path must end with /
APP_PATH = "/usr/share/system-config-xselector/"
ICON_PATH = APP_PATH + "pixmaps/system-config-xselector.png"
GLADE_FILE = "system-config-xselector.glade"
I18N_DOMAIN = "system-config-xselector"

class XselectorDialog:
    
    def __init__(self, isVerbose = False):
        self.selector = Xselector(isVerbose)
        xmlfn = APP_PATH + GLADE_FILE
        self.xml = gtk.glade.XML(xmlfn, "dialogGlxServer", domain=I18N_DOMAIN)
        self.dialogGlxServer = self.xml.get_widget("dialogGlxServer")
        self.buttonEnableAiglx = self.xml.get_widget("buttonEnableAiglx")
        self.buttonEnableXgl = self.xml.get_widget("buttonEnableXgl")
        self.buttonDisableAll = self.xml.get_widget("buttonDisableAll")
        self.applyButton = self.xml.get_widget("applyButton")
        self.closeButton = self.xml.get_widget("closeButton")
        self._initGui()
        self._connectSignals()
        try:
           iconPixbuf = gtk.gdk.pixbuf_new_from_file(ICON_PATH)
           self.dialogGlxServer.set_icon(iconPixbuf)
        except:
            pass
   
    def _connectSignals(self):
        self.applyButton.connect("clicked", self._apply)
        self.closeButton.connect("clicked", self._cancel)
        self.dialogGlxServer.connect("delete_event", self._cancel)
    
    def _initGui(self):
        currentConf = self.selector.getCurrentConfig()
        if currentConf == "aiglx":
            self.buttonEnableAiglx.activate()
        elif currentConf == "xgl":
            self.buttonEnableXgl.activate()
        else:
            self.buttonDisableAll.activate() 
        
    def _apply(self, *args):
        try:
            if self.buttonEnableAiglx.get_active():
                self._enableAiglx()
            if self.buttonEnableXgl.get_active():
                self._enableXgl()
            if self.buttonDisableAll.get_active():
                self._disableGlxStuff()
            self._confimation()
        except XselectorError, (errMsg):
            errorDialog = gtk.MessageDialog(self.dialogGlxServer,
                 type = gtk.MESSAGE_ERROR, buttons = gtk.BUTTONS_CLOSE,
                 message_format = str(errMsg))
            errorDialog.set_title(_("Error Dialog"))
            errorDialog.run()
            errorDialog.destroy()
            self._initGui()
 
    def _cancel(self, *args):
        gtk.main_quit()
        sys.exit(0)
    
    def _enableAiglx(self):
        self.selector.enableAiglx()
    
    def _enableXgl(self):
        self.selector.enableXgl()
    
    def _disableGlxStuff(self):
        self.selector.disableAllGlxStuff()
        
    def _confimation(self):
        info = gtk.MessageDialog(self.dialogGlxServer,
             type = gtk.MESSAGE_INFO, 
             buttons = gtk.BUTTONS_CLOSE,
             message_format = _("Configuration apply with sucess! \n\n The changes will be effective at the next X session"))
        info.set_title(_("Information Dialog"))
        info.run()
        info.destroy()

